gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r9506 - in gnunet/src: include nat upnp


From: gnunet
Subject: [GNUnet-SVN] r9506 - in gnunet/src: include nat upnp
Date: Sat, 14 Nov 2009 12:14:29 -0700

Author: grothoff
Date: 2009-11-14 12:14:29 -0700 (Sat, 14 Nov 2009)
New Revision: 9506

Modified:
   gnunet/src/include/gnunet_nat_lib.h
   gnunet/src/include/gnunet_scheduler_lib.h
   gnunet/src/nat/nat.c
   gnunet/src/nat/upnp.c
   gnunet/src/upnp/upnp.c
Log:
fixing doxygen comments

Modified: gnunet/src/include/gnunet_nat_lib.h
===================================================================
--- gnunet/src/nat/nat.c        2009-11-14 18:38:08 UTC (rev 9505)
+++ gnunet/src/nat/nat.c        2009-11-14 19:14:29 UTC (rev 9506)
@@ -110,7 +110,7 @@
 /**
  * Compare the sin(6)_addr fields of AF_INET or AF_INET(6) sockaddr.
  * @param a first sockaddr
- * @param second sockaddr
+ * @param b second sockaddr
  * @returns 0 if addresses are equal, non-null value otherwise */
 int
 GNUNET_NAT_cmp_addr (const struct sockaddr *a, const struct sockaddr *b)

Modified: gnunet/src/nat/upnp.c
===================================================================
--- gnunet/src/nat/upnp.c       2009-11-14 18:38:08 UTC (rev 9505)
+++ gnunet/src/nat/upnp.c       2009-11-14 19:14:29 UTC (rev 9506)
@@ -128,6 +128,7 @@
  * 
  * @param handle the handle for UPnP object
  * @param is_enabled whether enable port redirection
+ * @param doPortCheck FIXME
  * @param ext_addr pointer for returning external IP address.
  *     Will be set to NULL if address could not be found. Don't free the 
sockaddr.
  */

Modified: gnunet/src/upnp/upnp.c
===================================================================
--- gnunet/src/upnp/upnp.c      2009-11-14 18:38:08 UTC (rev 9505)
+++ gnunet/src/upnp/upnp.c      2009-11-14 19:14:29 UTC (rev 9506)
@@ -1,5 +1,5 @@
 /**
- * @file upnp.c UPnP Implementation
+ * @file upnp/upnp.c UPnP Implementation
  * @ingroup core
  *
  * gaim





reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- gnunet/src/include/gnunet_nat_lib.h 2009-11-14 18:38:08 UTC (rev 9505)
+++ gnunet/src/include/gnunet_nat_lib.h 2009-11-14 19:14:29 UTC (rev 9506)
@@ -70,7 +70,7 @@
 
 /**
  * Attempt to enable port redirection and detect public IP address contacting
- * UPnP or NAT-PMP routers on the local network. Use @addr to specify to which
+ * UPnP or NAT-PMP routers on the local network. Use addr to specify to which
  * of the local host's addresses should the external port be mapped. The port
  * is taken from the corresponding sockaddr_in[6] field.
  *

Modified: gnunet/src/include/gnunet_scheduler_lib.h
===================================================================
--- gnunet/src/include/gnunet_scheduler_lib.h   2009-11-14 18:38:08 UTC (rev 
9505)
+++ gnunet/src/include/gnunet_scheduler_lib.h   2009-11-14 19:14:29 UTC (rev 
9506)
@@ -271,14 +271,14 @@
  * and the reason code can be specified.
  *
  * @param sched scheduler to use
  * @param main main function of the task
  * @param cls closure of task
  * @param reason reason for task invocation
  */
 void
 GNUNET_SCHEDULER_add_continuation (struct GNUNET_SCHEDULER_Handle *sched,
-                                   GNUNET_SCHEDULER_Task main,
-                                   void *cls,
+                                   GNUNET_SCHEDULER_Task task,
+                                   void *task_cls,
                                    enum GNUNET_SCHEDULER_Reason reason);
 
 
@@ -271,14 +271,14 @@
  *
  * @param sched scheduler to use
- * @param main main function of the task
- * @param cls closure of task
+ * @param task main function of the task
+ * @param task_cls closure of task
  * @param reason reason for task invocation
  */

Modified: gnunet/src/nat/nat.c
===================================================================